@@ -76,58 +76,44 @@
 get_label <- function(x, ..., def.value = NULL, case = NULL) {
   # evaluate arguments, generate data
   x <- get_dot_data(x, dplyr::quos(...))
-  # auto-detect variable label attribute
-  attr.string <- getVarLabelAttribute(x)
 
   # do we have a df?
   if (is.data.frame(x)) {
-    # if yes, check if we have attached label table
-    # from foreign import
-    labels <- attr(x, "variable.labels", exact = T)
+    # iterate df
+    labels <- sapply(seq_along(x), function(i) {
 
-    # if not, get labels from each single vector
-    if (is.null(labels)) {
-      # iterate df
-      labels <- sapply(seq_along(x), function(i) {
-        # get label
-        if (!is.null(attr.string))
-          label <- attr(x[[i]], attr.string, exact = T)
+      # get label
+      label <- attr(x[[i]], "label", exact = T)
+
+      # any label?
+      if (!is.null(label)) {
+        # name label
+        names(label) <- colnames(x)[i]
+        # append to return result
+        return(convert_case(label, case))
+      } else if (!is.null(def.value)) {
+        # def.value may also apply to data frame arguments,
+        # so it can be greater than length one
+        if (i <= length(def.value))
+          return(convert_case(def.value[i], case))
         else
-          label <- NULL
-
-        # any label?
-        if (!is.null(label)) {
-          # name label
-          names(label) <- colnames(x)[i]
-          # append to return result
-          return(convert_case(label, case))
-        } else if (!is.null(def.value)) {
-          # def.value may also apply to data frame arguments,
-          # so it can be greater than length one
-          if (i <= length(def.value))
-            return(convert_case(def.value[i], case))
-          else
-            return(convert_case(def.value, case))
-        } else {
-          return("")
-        }
-      })
-    }
-    return(labels)
+          return(convert_case(def.value, case))
+      } else {
+        return("")
+      }
+    })
   } else if (is.list(x)) {
-    # nothing found? then leave...
-    if (is.null(attr.string)) return(NULL)
     # return attribute of all variables
-    return(convert_case(unlist(lapply(x, attr, attr.string, exact = T)), case))
+    labels <- convert_case(unlist(lapply(x, attr, "label", exact = T)), case)
   } else {
     # nothing found? then leave...
-    if (is.null(attr.string)) return(convert_case(def.value, case))
+    labels <- attr(x, "label", exact = T)
 
-    # else return attribute
-    retat <- attr(x, attr.string, exact = T)
-
-    # still NULL? than use default return value
-    if (is.null(retat)) retat <- def.value
-    return(convert_case(retat, case))
+    if (is.null(labels))
+      labels <- convert_case(def.value, case)
+    else
+      labels <- convert_case(labels, case)
   }
+
+  labels
 }
